@@ -39,8 +39,8 @@
 
 /********************************************************************************/
 
-GtkWidget   *mFile, *mTools, *mBatch, *mAlbums, *mMeta, *mArea;
-GtkWidget   *mEdit, *mRep, *mBend, *mEff, *mComb, *mHelp;
+GtkWidget   *mFile, *mTools, *mBatch, *mGmenu, *mMeta, *mArea;
+GtkWidget   *mEdit, *mRep, *mWarp, *mEff, *mComb, *mHelp;
 
 GtkWidget   *popmenu_main, *popmenu_thumb, *popmenu_album, *popmenu_raw;
 int         NFmenu, NGmenu, NWmenu, NMmenu;
@@ -61,7 +61,7 @@ void build_widgets()
    G_SIGNAL(Mwin,"destroy",destroy_event,0);
    G_SIGNAL(Mwin,"window-state-event",state_event,0);
    G_SIGNAL(Mwin,"key-press-event",KBpress,0);                                   //  connect KB events to main window
-   G_SIGNAL(Mwin,"key-release-event",KBrelease,0);
+   G_SIGNAL(Mwin,"key-release-event",KBrelease,0);                               //  16.11
 
    //  get hardware and set default font for screen widgets
    
@@ -96,6 +96,7 @@ void build_widgets()
    G_SIGNAL(Fdrawin,"motion-notify-event",mouse_event,0);
    G_SIGNAL(Fdrawin,"scroll-event",mouse_event,0);
    G_SIGNAL(Fdrawin,"draw",Fpaint,0);
+   drag_drop_dest(Fdrawin,drop_event);                                           //  accept drag-drop file              16.11
 
    //  G view widgets - thumbnail gallery
 
@@ -137,7 +138,7 @@ void build_widgets()
    drag_drop_source(Gdrawin,navi::gallery_dragfile);                             //  start file drag-drop               16.08
    drag_drop_dest(Gdrawin,navi::gallery_dropfile);                               //  accept drag-drop file              16.08
 
-   //  W view widgets - geomaps
+   //  W view widgets - local map files
 
    Whbox = gtk_box_new(HORIZONTAL,0);                                            //  top container
    gtk_box_pack_start(GTK_BOX(MWvbox),Whbox,1,1,0);
@@ -160,7 +161,7 @@ void build_widgets()
    G_SIGNAL(Wdrawin,"scroll-event",mouse_event,0);
    G_SIGNAL(Wdrawin,"draw",Fpaint,0);
 
-   //  M view widgets - OSM maps                                                 //  OSM                                16.05
+   //  M view widgets - OSM internet maps                                        //  OSM                                16.05
 
    Mhbox = gtk_box_new(HORIZONTAL,0);                                            //  top container
    gtk_box_pack_start(GTK_BOX(MWvbox),Mhbox,1,1,0);
@@ -189,18 +190,18 @@ void build_widgets()
    cchar * areas_tip = ZTX("Areas: Select areas to edit, copy and paste");
    cchar * edit_tip = ZTX("Edit: Trim, Rotate, Resize, Brightness, Contrast, Text ...");
    cchar * repair_tip = ZTX("Repair: Sharpen, Noise, Red-eyes, Color, Paint, Clone ...");
-   cchar * bend_tip = ZTX("Bend: Fix Perspective, Bend/Warp image ...");
+   cchar * warp_tip = ZTX("Warp: Fix Perspective, Warp or unwarp image ...");
    cchar * effects_tip = ZTX("Effects: Special Effects, Arty Transforms");
    cchar * combine_tip = ZTX("Combine: HDR, HDF, Panorama, Stack, Mashup");
    cchar * undo_redo_tip = ZTX("left/right click: undo/redo 1 edit \n"
                                " with key A: undo/redo all edits \n"
                                " middle click: go to any prior edit");
+   cchar * batch_tip = ZTX("Batch image processing, batch metadata, Search ...");
    cchar * tools_tip = ZTX("Tools: Index, Options, Shortcuts, Magnify ...");
    cchar * help_tip = ZTX("Help: Quick Start, User Guide, Recent Changes ...");
 
    //  G view menu buttons
-   cchar * sync_tip = ZTX("Set gallery from current image file");
-   cchar * albums_tip = ZTX("Albums: Manage Albums, Slide Show, Desktop Wallpaper");
+   cchar * gmenu_tip = ZTX("Sync Gallery, Export, Flickr, Albums, Slide Show");
    cchar * bookmarks_tip = ZTX("go to bookmarked image");
    cchar * thumb_increase_tip = ZTX("increase thumbnail size");
    cchar * thumb_reduce_tip = ZTX("reduce thumbnail size");
@@ -210,19 +211,12 @@ void build_widgets()
    cchar * previous_page_tip = ZTX("previous page");
    cchar * next_page_tip = ZTX("next page");
    cchar * slow_scroll_tip = ZTX("slow scroll");
-   cchar * batch_tip = ZTX("Batch conversion, metadata, RAW processing");
 
    //  W view menu buttons
-   cchar * load_geomap_tip = ZTX("Choose a map for image locations");
-   cchar * mapsearch_tip = ZTX("Set image search radius for map click");
-   cchar * search_images_tip = ZTX("Find images meeting select criteria");
-   cchar * locations_tip = ZTX("Find all images for a location [date]");
-   cchar * timeline_tip = ZTX("Show image counts by month, select and report");
+   cchar * load_geomap_tip = ZTX("Choose a map file");
 
    //  M view menu buttons                                                       //  OSM                                16.05
-   //  search_images_tip (duplicate of W view)
-   //  locations_tip (duplicate of W view)
-   //  timeline_tip (duplicate of W view)
+   cchar * OSM_map_source_tip = ZTX("Choose Internet map source");
 
    //  file popup menu
    cchar * clone_tip = ZTX("Open another window");
@@ -233,6 +227,7 @@ void build_widgets()
    cchar * rawtherapee_tip = ZTX("Open and edit a camera RAW file");
    cchar * rename_tip = ZTX("Change the image file name");
    cchar * copy_move_tip = ZTX("Copy or Move an image file to a new location");
+   cchar * copyto_desktop_tip = ZTX("Copy an image file to the desktop");
    cchar * create_tip = ZTX("Create a blank image");
    cchar * deltrash_tip = ZTX("Delete or trash image file");
    cchar * print_tip = ZTX("Print the current image");
@@ -251,9 +246,9 @@ void build_widgets()
    cchar * batch_change_metadata_tip = ZTX("Add/change/delete metadata for multiple images");
    cchar * batch_report_metadata_tip = ZTX("Report metadata for multiple images");
    cchar * batch_geotags_tip = ZTX("Add/revise geotags for multiple images");
-   //  search_images_tip (duplicate of W view)
-   //  locations_tip (duplicate of W view)
-   //  timeline_tip (duplicate of W view)
+   cchar * locations_tip = ZTX("Find all images for a location [date]");
+   cchar * timeline_tip = ZTX("Show image counts by month, select and report");
+   cchar * search_images_tip = ZTX("Find images meeting select criteria");
 
    //  select area popup menu
    cchar * select_tip = ZTX("Select object or area for editing");
@@ -310,16 +305,18 @@ void build_widgets()
    cchar * color_fringes_tip = ZTX("Reduce Chromatic Abberation");
    cchar * stuck_pixels_tip = ZTX("Erase known hot and dark pixels");
 
-   //  bend popup menu
+   //  warp popup menu
    cchar * unbend_tip = ZTX("Remove curvature, esp. panoramas");
    cchar * perspective_tip = ZTX("Straighten objects seen from an angle");
    cchar * warp_area_tip = ZTX("Distort image areas using the mouse");
+   cchar * unwarp_closeup_tip = ZTX("Unwarp closeup face photo to remove distortion");
    cchar * warp_curved_tip = ZTX("Distort the whole image using the mouse");
    cchar * warp_linear_tip = ZTX("Distort the whole image using the mouse");
    cchar * warp_affine_tip = ZTX("Distort the whole image using the mouse");
    cchar * flatbook_tip = ZTX("Flatten a photographed book page");
    cchar * sphere_tip = ZTX("Make a spherical projection of an image");
    cchar * selective_rescale_tip = ZTX("Rescale image outside selected areas");
+   cchar * waves_tip = ZTX("Warp an image with a wave pattern");
 
    //  effects popup menu
    cchar * colordep_tip = ZTX("Reduce color depth (posterize)");
@@ -337,7 +334,6 @@ void build_widgets()
    cchar * pattern_tip = ZTX("Tile image with a repeating pattern");
    cchar * mosaic_tip = ZTX("Create a mosaic with tiles made from all images");
    cchar * anykernel_tip = ZTX("Process an image using a custom kernel");
-   cchar * waves_tip = ZTX("Warp an image with a wave pattern");
    cchar * dirblur_tip = ZTX("Blur an image in the direction of mouse drags");
    cchar * blur_BG_tip = ZTX("Increasing blur with distance from selected areas");
 
@@ -366,8 +362,10 @@ void build_widgets()
    cchar * changelang_tip = ZTX("Change the GUI language");
    cchar * untranslated_tip = ZTX("Report missing translations");
    cchar * calibrate_printer_tip = ZTX("Calibrate printer colors");
+   cchar * setdesktop_tip = ZTX("Set desktop wallpaper from current Fotoxx image");
+   cchar * cycledesktop_tip = ZTX("Cycle desktop wallpaper from a Fotoxx album");
    cchar * resources_tip = ZTX("Memory and CPU (to terminal/logfile)");
-// cchar * zappcrash_tip = "deliberate crash with traceback dump";
+   cchar * zappcrash_tip = "deliberate crash with traceback dump";
 
    //  batch popup menu
    cchar * batch_convert_tip = ZTX("Rename/convert/resize/move multiple files");
@@ -378,7 +376,7 @@ void build_widgets()
    cchar * scriptfiles_tip = ZTX("Build and run edit script files");
    cchar * burn_tip = ZTX("Burn selected image files to DVD/BlueRay disc");
    cchar * duplicates_tip = ZTX("Search all image files and report duplicates");
-   cchar * imagelist_tip = ZTX("Create a file of selected image files");
+   cchar * export_filelist_tip = ZTX("Create a file of selected image files");
    //  metadata batch functions are duplicated here
 
    //  help popup menu
@@ -393,11 +391,14 @@ void build_widgets()
    cchar * homepage_tip = ZTX("Show the Fotoxx web page");
    cchar * about_tip = ZTX("Version, license, contact, credits");
 
-   //  albums popup menu
+   //  gallery popup menu
+   cchar * sync_gallery_tip = ZTX("Set gallery from current image file");
+   cchar * export_images_tip = ZTX("Export selected image files to a directory");
+   cchar * flickr_upload_tip = ZTX("Upload image files to Flickr web service");
    cchar * manage_albums_tip = ZTX("Organize images into albums");
+   cchar * update_albums_tip = ZTX("Update album files to latest version");
+   cchar * replace_album_file_tip = ZTX("Replace album file with another file");
    cchar * slideshow_tip = ZTX("Start a slide show");
-   cchar * setdesktop_tip = ZTX("Set desktop wallpaper from current Fotoxx image");
-   cchar * cycledesktop_tip = ZTX("Cycle desktop wallpaper from a Fotoxx album");
 
 
    //  build menu entries -------------------------------------------------
@@ -421,7 +422,7 @@ void build_widgets()
 
    mFile = create_popmenu();
    MENUENT(mFile,    ZTX("New Window"), 0,                  clone_tip,              m_clone, 0 );
-   MENUENT(mFile,    ZTX("Sync Gallery"), 0,                sync_tip,               navi::menufuncx, 0 );
+   MENUENT(mFile,    ZTX("Sync Gallery"), 0,                sync_gallery_tip,       m_sync_gallery, 0 );
    MENUENT(mFile,    ZTX("Recently Seen Images"), 0,        recentfiles_tip,        m_recentfiles, 0 );
    MENUENT(mFile,    ZTX("Newest Images"), 0,               newfiles_tip,           m_newfiles, 0 );
    MENUENT(mFile,    ZTX("Open Image File"), 0,             open_tip,               m_open, 0 );
@@ -430,10 +431,10 @@ void build_widgets()
    MENUENT(mFile,    ZTX("New Blank Image"), 0,             create_tip,             m_create, 0 );
    MENUENT(mFile,    ZTX("Rename Image File"), 0,           rename_tip,             m_rename, 0 );
    MENUENT(mFile,    ZTX("Copy/Move to Location"), 0,       copy_move_tip,          m_copy_move, 0 );
+   MENUENT(mFile,    ZTX("Copy to Desktop"), 0,             copyto_desktop_tip,     m_copyto_desktop, 0 );
    MENUENT(mFile,    ZTX("Delete/Trash Image File"), 0,     deltrash_tip,           m_delete_trash, 0 );
    MENUENT(mFile,    ZTX("Print Image"), 0,                 print_tip,              m_print, 0 );
    MENUENT(mFile,    ZTX("Print Calibrated Image"), 0,      print_calibrated_tip,   m_print_calibrated, 0 );
-   MENUENT(mFile,    ZTX("Set Desktop Wallpaper"), 0,       setdesktop_tip,         m_setdesktop, 0 );
    MENUENT(mFile,    ZTX("Quit Fotoxx"), 0,                 quit_tip,               m_quit, 0 );
 
    mMeta = create_popmenu();
@@ -448,9 +449,9 @@ void build_widgets()
    MENUENT(mMeta,    ZTX("Batch Add/Change Metadata"), 0,   batch_change_metadata_tip,    m_batch_change_metadata, 0 );
    MENUENT(mMeta,    ZTX("Batch Report Metadata"), 0,       batch_report_metadata_tip,    m_batch_report_metadata, 0 );
    MENUENT(mMeta,    ZTX("Batch Add Geotags"), 0,           batch_geotags_tip,            m_batch_geotags, 0 );
-   MENUENT(mMeta,    ZTX("Search Images"), 0,               search_images_tip,            m_search_images, 0 );
    MENUENT(mMeta,    ZTX("Image Locations/Dates"), 0,       locations_tip,                m_locations, 0 );
    MENUENT(mMeta,    ZTX("Image Timeline"), 0,              timeline_tip,                 m_timeline, 0 );
+   MENUENT(mMeta,    ZTX("Search Images"), 0,               search_images_tip,            m_search_images, 0 );
 
    mArea = create_popmenu();
    MENUENT(mArea,    ZTX("Select"), 0,             select_tip,                m_select, 0 );
@@ -479,7 +480,7 @@ void build_widgets()
    MENUENT(mEdit,    ZTX("Resize"), 0,                   resize_tip,                m_resize, 0 );
    MENUENT(mEdit,    ZTX("Flip"), 0,                     flip_tip,                  m_flip, 0 );
    MENUENT(mEdit,    ZTX("Add Text"), 0,                 write_text_tip,            m_write_text, 0 );
-   MENUENT(mEdit,    ZTX("Add Lines"), 0,                write_line_tip,            m_write_line, 0 );
+   MENUENT(mEdit,    ZTX("Add Lines/Arrows"), 0,         write_line_tip,            m_write_line, 0 );
    MENUENT(mEdit,    ZTX("Paint Edits"), 0,              paint_edits_tip,           m_paint_edits, 0 );
    MENUENT(mEdit,    ZTX("Leverage Edits"), 0,           lever_edits_tip,           m_lever_edits, 0 );
    MENUENT(mEdit,    ZTX("Plugins"), 0,                  plugins_tip,               m_plugins, 0);
@@ -507,16 +508,18 @@ void build_widgets()
    MENUENT(mRep,     ZTX("Color Fringes"), 0,         color_fringes_tip,      m_color_fringes, 0 );
    MENUENT(mRep,     ZTX("Stuck Pixels"), 0,          stuck_pixels_tip,       m_stuck_pixels, 0 );
 
-   mBend = create_popmenu();
-   MENUENT(mBend,    ZTX("Unbend"), 0,                unbend_tip,             m_unbend, 0 );
-   MENUENT(mBend,    ZTX("Fix Perspective"), 0,       perspective_tip,        m_perspective, 0 );
-   MENUENT(mBend,    ZTX("Warp area"), 0,             warp_area_tip,          m_warp_area, 0 );
-   MENUENT(mBend,    ZTX("Warp curved"), 0,           warp_curved_tip,        m_warp_curved, 0 );
-   MENUENT(mBend,    ZTX("Warp linear"), 0,           warp_linear_tip,        m_warp_linear, 0 );
-   MENUENT(mBend,    ZTX("Warp affine"), 0,           warp_affine_tip,        m_warp_affine, 0 );
-   MENUENT(mBend,    ZTX("Flatten Book Page"), 0,     flatbook_tip,           m_flatbook, 0 );
-   MENUENT(mBend,    ZTX("Spherical Projection"), 0,  sphere_tip,             m_sphere, 0);
-   MENUENT(mBend,    ZTX("Selective Rescale"), 0,     selective_rescale_tip,  m_selective_rescale, 0);
+   mWarp = create_popmenu();
+   MENUENT(mWarp,    ZTX("Unbend"), 0,                unbend_tip,             m_unbend, 0 );
+   MENUENT(mWarp,    ZTX("Fix Perspective"), 0,       perspective_tip,        m_perspective, 0 );
+   MENUENT(mWarp,    ZTX("Warp area"), 0,             warp_area_tip,          m_warp_area, 0 );
+   MENUENT(mWarp,    ZTX("Unwarp Closeup"), 0,        unwarp_closeup_tip,     m_unwarp_closeup, 0 );
+   MENUENT(mWarp,    ZTX("Warp curved"), 0,           warp_curved_tip,        m_warp_curved, 0 );
+   MENUENT(mWarp,    ZTX("Warp linear"), 0,           warp_linear_tip,        m_warp_linear, 0 );
+   MENUENT(mWarp,    ZTX("Warp affine"), 0,           warp_affine_tip,        m_warp_affine, 0 );
+   MENUENT(mWarp,    ZTX("Flatten Book Page"), 0,     flatbook_tip,           m_flatbook, 0 );
+   MENUENT(mWarp,    ZTX("Spherical Projection"), 0,  sphere_tip,             m_sphere, 0);
+   MENUENT(mWarp,    ZTX("Selective Rescale"), 0,     selective_rescale_tip,  m_selective_rescale, 0);
+   MENUENT(mWarp,    ZTX("Make Waves"), 0,            waves_tip,              m_waves, 0);
 
    mEff = create_popmenu();
    MENUENT(mEff,     ZTX("Color Depth"), 0,           colordep_tip,        m_colordep, 0 );
@@ -534,7 +537,6 @@ void build_widgets()
    MENUENT(mEff,     ZTX("Pattern"), 0,               pattern_tip,         m_pattern, 0 );
    MENUENT(mEff,     ZTX("Mosaic"), 0,                mosaic_tip,          m_mosaic, 0);
    MENUENT(mEff,     ZTX("Custom Kernel"), 0,         anykernel_tip,       m_anykernel, 0);
-   MENUENT(mEff,     ZTX("Make Waves"), 0,            waves_tip,           m_waves, 0);
    MENUENT(mEff,     ZTX("Directed Blur"), 0,         dirblur_tip,         m_dirblur, 0);
    MENUENT(mEff,     ZTX("Blur Background"), 0,       blur_BG_tip,         m_blur_BG, 0);
 
@@ -548,6 +550,26 @@ void build_widgets()
    MENUENT(mComb,    ZTX("PT Panorama"), 0,              pano_PT_tip,         m_pano_PT, 0 );
    MENUENT(mComb,    ZTX("Mashup"), 0,                   mashup_tip,          m_mashup, 0 );
 
+   mBatch = create_popmenu();
+   MENUENT(mBatch,   ZTX("Batch Convert"), 0,               batch_convert_tip,         m_batch_convert, 0 );
+   MENUENT(mBatch,   ZTX("Batch Upright"), 0,               batch_upright_tip,         m_batch_upright, 0 );
+   MENUENT(mBatch,   ZTX("Batch Delete/Trash"), 0,          batch_deltrash_tip,        m_batch_deltrash, 0 );
+   MENUENT(mBatch,   ZTX("Batch RAW"), 0,                   batch_raw_tip,             m_batch_raw, 0 );            //  16.07
+   MENUENT(mBatch,   ZTX("Batch Raw Therapee"), 0,          batch_rawtherapee_tip,     m_batch_rawtherapee, 0 );    //  16.07
+   MENUENT(mBatch,   ZTX("Script Files"), 0,                scriptfiles_tip,           m_scriptfiles, 0 );
+   MENUENT(mBatch,   ZTX("Burn Images to DVD/BlueRay"), 0,  burn_tip,                  m_burn, 0 );
+   MENUENT(mBatch,   ZTX("Find Duplicate Images"), 0,       duplicates_tip,            m_duplicates, 0 );
+   MENUENT(mBatch,   ZTX("Export File List"), 0,            export_filelist_tip,       m_export_filelist, 0 );
+   // duplicates of metadata menu follow:
+   MENUENT(mBatch,   ZTX("Batch Add/Remove Tags"), 0,       batch_tags_tip,               m_batch_tags, 0 );
+   MENUENT(mBatch,   ZTX("Batch Rename Tags"), 0,           batch_rename_tags_tip,        m_batch_rename_tags, 0 );
+   MENUENT(mBatch,   ZTX("Batch Add/Change Metadata"), 0,   batch_change_metadata_tip,    m_batch_change_metadata, 0 );
+   MENUENT(mBatch,   ZTX("Batch Report Metadata"), 0,       batch_report_metadata_tip,    m_batch_report_metadata, 0 );
+   MENUENT(mBatch,   ZTX("Batch Add Geotags"), 0,           batch_geotags_tip,            m_batch_geotags, 0 );
+   MENUENT(mBatch,   ZTX("Image Locations/Dates"),  0,      locations_tip,                m_locations, 0 );
+   MENUENT(mBatch,   ZTX("Image Timeline"), 0,              timeline_tip,                 m_timeline, 0 );
+   MENUENT(mBatch,   ZTX("Search Images"),     0,           search_images_tip,            m_search_images, 0 );
+
    mTools = create_popmenu();
    MENUENT(mTools,   ZTX("Index Image Files"), 0,           index_tip,                 m_index, 0 );
    MENUENT(mTools,   ZTX("User Options"), 0,                options_tip,               m_options, 0 );
@@ -563,34 +585,10 @@ void build_widgets()
    MENUENT(mTools,   ZTX("Change Language"), 0,             changelang_tip,            m_changelang, 0 );
    MENUENT(mTools,   ZTX("Missing Translations"), 0,        untranslated_tip,          m_untranslated, 0 );
    MENUENT(mTools,   ZTX("Calibrate Printer"), 0,           calibrate_printer_tip,     m_calibrate_printer, 0 );
+   MENUENT(mTools,   ZTX("Set Desktop Wallpaper"), 0,       setdesktop_tip,            m_setdesktop, 0 );
+   MENUENT(mTools,   ZTX("Cycle Desktop Wallpaper"), 0,     cycledesktop_tip,          m_cycledesktop, 0 );
    MENUENT(mTools,   ZTX("Resources"), 0,                   resources_tip,             m_resources, 0 );
-// MENUENT(mTools,   ZTX("zappcrash test"), 0,              zappcrash_tip,             m_zappcrash, 0 ); 
-
-   mBatch = create_popmenu();
-   MENUENT(mBatch,   ZTX("Batch Convert"), 0,               batch_convert_tip,         m_batch_convert, 0 );
-   MENUENT(mBatch,   ZTX("Batch Upright"), 0,               batch_upright_tip,         m_batch_upright, 0 );
-   MENUENT(mBatch,   ZTX("Batch Delete/Trash"), 0,          batch_deltrash_tip,        m_batch_deltrash, 0 );
-   MENUENT(mBatch,   ZTX("Batch RAW"), 0,                   batch_raw_tip,             m_batch_raw, 0 );            //  16.07
-   MENUENT(mBatch,   ZTX("Batch Raw Therapee"), 0,          batch_rawtherapee_tip,     m_batch_rawtherapee, 0 );    //  16.07
-   MENUENT(mBatch,   ZTX("Script Files"), 0,                scriptfiles_tip,           m_scriptfiles, 0 );
-   MENUENT(mBatch,   ZTX("Burn Images to DVD/BlueRay"), 0,  burn_tip,                  m_burn, 0 );
-   MENUENT(mBatch,   ZTX("Find Duplicate Images"), 0,       duplicates_tip,            m_duplicates, 0 );
-   MENUENT(mBatch,   ZTX("Create File of Image Files"), 0,  imagelist_tip,             m_imagelist, 0 );
-   // duplicates of metadata menu
-   MENUENT(mBatch,   ZTX("Batch Add/Remove Tags"), 0,       batch_tags_tip,               m_batch_tags, 0 );
-   MENUENT(mBatch,   ZTX("Batch Rename Tags"), 0,           batch_rename_tags_tip,        m_batch_rename_tags, 0 );
-   MENUENT(mBatch,   ZTX("Batch Add/Change Metadata"), 0,   batch_change_metadata_tip,    m_batch_change_metadata, 0 );
-   MENUENT(mBatch,   ZTX("Batch Report Metadata"), 0,       batch_report_metadata_tip,    m_batch_report_metadata, 0 );
-   MENUENT(mBatch,   ZTX("Batch Add Geotags"), 0,           batch_geotags_tip,            m_batch_geotags, 0 );
-   MENUENT(mBatch,   ZTX("Image Locations/Dates"),  0,      locations_tip,                m_locations, 0 );
-   MENUENT(mBatch,   ZTX("Image Timeline"), 0,              timeline_tip,                 m_timeline, 0 );
-   MENUENT(mBatch,   ZTX("Search Images"),     0,           search_images_tip,            m_search_images, 0 );
-
-   mAlbums = create_popmenu();
-   MENUENT(mAlbums,  ZTX("Manage Albums"), 0,               manage_albums_tip,         m_manage_albums, 0 );
-   MENUENT(mAlbums,  ZTX("Slide Show"), 0,                  slideshow_tip,             m_slideshow, 0 );
-   MENUENT(mAlbums,  ZTX("Set Desktop Wallpaper"), 0,       setdesktop_tip,            m_setdesktop, 0 );
-   MENUENT(mAlbums,  ZTX("Cycle Desktop Wallpaper"), 0,     cycledesktop_tip,          m_cycledesktop, 0 );
+   MENUENT(mTools,       "zappcrash test", 0,               zappcrash_tip,             m_zappcrash, 0 ); 
 
    mHelp = create_popmenu();
    MENUENT(mHelp,    ZTX("Quick Start"), 0,              quick_start_tip,           m_help, 0 );
@@ -604,6 +602,15 @@ void build_widgets()
    MENUENT(mHelp,    ZTX("Home Page"), 0,                homepage_tip,              m_help, 0 );
    MENUENT(mHelp,    ZTX("About"), 0,                    about_tip,                 m_help, 0 );
 
+   mGmenu = create_popmenu();
+   MENUENT(mGmenu,   ZTX("Sync Gallery"), 0,                sync_gallery_tip,          m_sync_gallery, 0 );
+   MENUENT(mGmenu,   ZTX("Export Image Files"), 0,          export_images_tip,         m_export_images, 0 );
+   MENUENT(mGmenu,   ZTX("Upload to Flickr"), 0,            flickr_upload_tip,         m_flickr_upload, 0 );
+   MENUENT(mGmenu,   ZTX("Manage Albums"), 0,               manage_albums_tip,         m_manage_albums, 0 );
+   MENUENT(mGmenu,   ZTX("Update Album Files"), 0,          update_albums_tip,         m_update_albums, 0 );
+   MENUENT(mGmenu,   ZTX("Replace Album File"), 0,          replace_album_file_tip,    m_replace_album_file, 0 );
+   MENUENT(mGmenu,   ZTX("Slide Show"), 0,                  slideshow_tip,             m_slideshow, 0 );
+
    //  F view menu (buttons) 
 
    MENUENT(0,  Bimage,              "viewF-check.png",   imagefile_tip,       m_viewmode, "F" );
@@ -619,10 +626,11 @@ void build_widgets()
    MENUENT(0,  ZTX("Areas"),        "areas.png",         areas_tip,           (cbFunc *) popup_menu, (cchar *) mArea);
    MENUENT(0,  ZTX("Edit"),         "edit.png",          edit_tip,            (cbFunc *) popup_menu, (cchar *) mEdit);
    MENUENT(0,  ZTX("Repair"),       "repair.png",        repair_tip,          (cbFunc *) popup_menu, (cchar *) mRep);
-   MENUENT(0,  ZTX("Bend"),         "bend.png",          bend_tip,            (cbFunc *) popup_menu, (cchar *) mBend);
+   MENUENT(0,  ZTX("Warp"),         "warp.png",          warp_tip,            (cbFunc *) popup_menu, (cchar *) mWarp);
    MENUENT(0,  ZTX("Effects"),      "effects.png",       effects_tip,         (cbFunc *) popup_menu, (cchar *) mEff);
    MENUENT(0,  ZTX("Combine"),      "combine.png",       combine_tip,         (cbFunc *) popup_menu, (cchar *) mComb);
    MENUENT(0,  ZTX("Undo/Redo"),    "undo_redo.png",     undo_redo_tip,       m_undo_redo, 0 );
+   MENUENT(0,  ZTX("Batch"),        "batch.png",         batch_tip,           (cbFunc *) popup_menu, (cchar *) mBatch);
    MENUENT(0,  ZTX("Tools"),        "tools.png",         tools_tip,           (cbFunc *) popup_menu, (cchar *) mTools);
    MENUENT(0,  ZTX("Help"),         "help.png",          help_tip,            (cbFunc *) popup_menu, (cchar *) mHelp);
 
@@ -636,8 +644,7 @@ void build_widgets()
    MENUENT(0,  ZTX("OSM Maps"),     "viewM.png",         OSMmaps_tip,            m_viewmode, "M" );            //  OSM  16.05
    MENUENT(0,  0,                   "separator.png",     0,                      0,           0  );
    MENUENT(0,  ZTX("Favorites"),    "favorites.png",     favorites_tip,          m_favorites, 0 );
-   MENUENT(0,  ZTX("Sync Gallery"), "sync.png",          sync_tip,               navi::menufuncx, 0 );
-   MENUENT(0,  ZTX("Albums"),       "albums.png",        albums_tip,             (cbFunc *) popup_menu, (cchar *) mAlbums);
+   MENUENT(0,      "Menu",          "gmenu.png",         gmenu_tip,              (cbFunc *) popup_menu, (cchar *) mGmenu);
    MENUENT(0,  ZTX("Bookmarks"),    "goto.png",          bookmarks_tip,          m_goto_bookmark, 0 );
    MENUENT(0,  ZTX("Zoom+"),        "zoom+.png",         thumb_increase_tip,     navi::menufuncx, 0 );
    MENUENT(0,  ZTX("Zoom-"),        "zoom-.png",         thumb_reduce_tip,       navi::menufuncx, 0 );
@@ -648,6 +655,7 @@ void build_widgets()
    MENUENT(0,  ZTX("Page↓"),       "down.png",          next_page_tip,          navi::menufuncx, 0 );
    MENUENT(0,  ZTX("Scroll"),       "scroll.png",        slow_scroll_tip,        navi::menufuncx, 0 );
    MENUENT(0,  ZTX("Batch"),        "batch.png",         batch_tip,              (cbFunc *) popup_menu, (cchar *) mBatch);
+   MENUENT(0,  ZTX("Tools"),        "tools.png",         tools_tip,              (cbFunc *) popup_menu, (cchar *) mTools);
    MENUENT(0,  ZTX("Help"),         "help.png",          help_tip,               (cbFunc *) popup_menu, (cchar *) mHelp);
 
    NGmenu = Nmenus;                                                              //  end of G view menus
@@ -660,10 +668,6 @@ void build_widgets()
    MENUENT(0,  ZTX("OSM Maps"),                 "viewM.png",            OSMmaps_tip,         m_viewmode, "M" );      //  OSM  16.05
    MENUENT(0,  0,                               "separator.png",        0,                   0,           0  );
    MENUENT(0,  ZTX("Choose Map"),               "choosemap.png",        load_geomap_tip,     m_load_geomap, 0 );
-   MENUENT(0,  ZTX("Search Range"),             "setmaprange.png",      mapsearch_tip,       m_mapsearch_range, 0 );
-   MENUENT(0,  ZTX("Image Locations/Dates"),    "search.png",           locations_tip,       m_locations, 0 );
-   MENUENT(0,  ZTX("Image Timeline"),           "search.png",           timeline_tip,        m_timeline, 0 );
-   MENUENT(0,  ZTX("Search Images"),            "search.png",           search_images_tip,   m_search_images, 0 );
 
    NWmenu = Nmenus;                                                              //  end of W view menus
 
@@ -674,9 +678,7 @@ void build_widgets()
    MENUENT(0,  ZTX("World Maps"),               "viewW.png",            worldmaps_tip,       m_viewmode, "W" );
    MENUENT(0,  ZTX("OSM Maps"),                 "viewM-check.png",      OSMmaps_tip,         m_viewmode, "M" );
    MENUENT(0,  0,                               "separator.png",        0,                   0,           0  );
-   MENUENT(0,  ZTX("Image Locations/Dates"),    "search.png",           locations_tip,       m_locations, 0 );
-   MENUENT(0,  ZTX("Image Timeline"),           "search.png",           timeline_tip,        m_timeline, 0 );
-   MENUENT(0,  ZTX("Search Images"),            "search.png",           search_images_tip,   m_search_images, 0 );
+   MENUENT(0,  ZTX("Choose Map"),               "choosemap.png",        OSM_map_source_tip,  m_OSM_map_source, 0 );
 
    NMmenu = Nmenus;                                                              //  end of M view menus
 
@@ -734,6 +736,7 @@ void build_widgets()
    cchar    *menumeta3 = ZTX("Edit Any Metadata");
    cchar    *menurename = ZTX("Rename");
    cchar    *menucopymove = ZTX("Copy/Move to Location");
+   cchar    *menucopytodesktop = ZTX("Copy to Desktop");
    cchar    *menucopytoclip = ZTX("Copy to Clipboard");
    cchar    *menuremovefromalbum = ZTX("Remove from Album");
    cchar    *menucuttocache = ZTX("Cut to Image Cache");
@@ -754,12 +757,13 @@ void build_widgets()
    cchar    *menuOSMzoom = ZTX("Show on OSM Map");
    cchar    *menudeltrash = ZTX("Delete/Trash ...");
 
-   popmenu_main = create_popmenu();                                              //  main window image
+   popmenu_main = create_popmenu();                                              //  main window popup menu
    add_popmenu_item(popmenu_main,menumeta1,popup_menufunc,"view metadata");
    add_popmenu_item(popmenu_main,menumeta2,popup_menufunc,"edit metadata");
    add_popmenu_item(popmenu_main,menumeta3,popup_menufunc,"edit any metadata");
    add_popmenu_item(popmenu_main,menurename,popup_menufunc,"rename");
    add_popmenu_item(popmenu_main,menucopymove,popup_menufunc,"copymove");
+   add_popmenu_item(popmenu_main,menucopytodesktop,popup_menufunc,"copytodesktop");
    add_popmenu_item(popmenu_main,menucopytocache,popup_menufunc,"copytocache");
    add_popmenu_item(popmenu_main,menucopytoclip,popup_menufunc,"copytoclip");
    add_popmenu_item(popmenu_main,menuupright,popup_menufunc,"upright");
@@ -775,27 +779,30 @@ void build_widgets()
    add_popmenu_item(popmenu_main,menuOSMzoom,popup_menufunc,"OSM_zoomin");
    add_popmenu_item(popmenu_main,menudeltrash,popup_menufunc,"delete/trash");
 
-   popmenu_thumb = create_popmenu();                                             //  gallery thumbnail
+   popmenu_thumb = create_popmenu();                                             //  gallery thumbnail popup menu
    add_popmenu_item(popmenu_thumb,menupopimage,popup_menufunc,"popimage");
    add_popmenu_item(popmenu_thumb,menumeta1,popup_menufunc,"view metadata");
    add_popmenu_item(popmenu_thumb,menumeta2,popup_menufunc,"edit metadata");
    add_popmenu_item(popmenu_thumb,menumeta3,popup_menufunc,"edit any metadata");
    add_popmenu_item(popmenu_thumb,menurename,popup_menufunc,"rename");
    add_popmenu_item(popmenu_thumb,menucopymove,popup_menufunc,"copymove");
+   add_popmenu_item(popmenu_thumb,menucopytodesktop,popup_menufunc,"copytodesktop");
    add_popmenu_item(popmenu_thumb,menucopytocache,popup_menufunc,"copytocache");
    add_popmenu_item(popmenu_thumb,menucopytoclip,popup_menufunc,"copytoclip");
    add_popmenu_item(popmenu_thumb,menuupright,popup_menufunc,"upright");
    add_popmenu_item(popmenu_thumb,menuOSMzoom,popup_menufunc,"OSM_zoomin");
    add_popmenu_item(popmenu_thumb,menudeltrash,popup_menufunc,"delete/trash");
 
-   popmenu_raw = create_popmenu();                                               //  gallery thumbnail, RAW file
+   popmenu_raw = create_popmenu();                                               //  gallery thumbnail-RAW popup menu
+   add_popmenu_item(popmenu_raw,menupopimage,popup_menufunc,"popimage");         //  16.09
    add_popmenu_item(popmenu_raw,menuopenraw,m_rawtherapee,0);
    add_popmenu_item(popmenu_raw,menumeta1,popup_menufunc,"view metadata");
    add_popmenu_item(popmenu_raw,menurename,popup_menufunc,"rename");
    add_popmenu_item(popmenu_raw,menucopymove,popup_menufunc,"copymove");
    add_popmenu_item(popmenu_raw,menudeltrash,popup_menufunc,"delete/trash");
 
-   popmenu_album = create_popmenu();                                             //  album gallery thumbnail
+   popmenu_album = create_popmenu();                                             //  album gallery thumbnail popup menu
+   add_popmenu_item(popmenu_album,menupopimage,popup_menufunc,"popimage");
    add_popmenu_item(popmenu_album,menucopytocache,popup_menufunc,"copytocache");
    add_popmenu_item(popmenu_album,menucuttocache,popup_menufunc,"cuttocache");
    add_popmenu_item(popmenu_album,menucopytoclip,popup_menufunc,"copytoclip");
@@ -804,6 +811,7 @@ void build_widgets()
    add_popmenu_item(popmenu_album,menuremovefromalbum,popup_menufunc,"removefromalbum");
    add_popmenu_item(popmenu_album,menupopimage,popup_menufunc,"popimage");
    add_popmenu_item(popmenu_album,menumeta1,popup_menufunc,"view metadata");
+   add_popmenu_item(popmenu_album,menucopytodesktop,popup_menufunc,"copytodesktop");
 
    return;
 }
@@ -813,13 +821,14 @@ void build_widgets()
 
 void popup_menufunc(GtkWidget *, cchar *menu)
 {
-   if (strmatch(menu,"popimage")) popimage();                                    //  funcs for main and gallery windows
+   if (strmatch(menu,"popimage")) gallery_popimage();                            //  funcs for main and gallery windows
    if (strmatch(menu,"view metadata")) meta_view(1);
    if (strmatch(menu,"edit metadata")) m_edit_metadata(0,0);
    if (strmatch(menu,"edit any metadata")) m_meta_edit_any(0,0);                 //  16.06
    if (strmatch(menu,"rename")) m_rename(0,0);                                   //  these use clicked_file if defined,
    if (strmatch(menu,"upright")) m_upright(0,0);                                 //    else they use curr_file.
    if (strmatch(menu,"copymove")) m_copy_move(0,0);                              //  16.06
+   if (strmatch(menu,"copytodesktop")) m_copyto_desktop(0,0);                    //  16.09
    if (strmatch(menu,"delete/trash")) m_delete_trash(0,0);                       //  16.06
    if (strmatch(menu,"OSM_zoomin")) m_OSM_zoomin(0,0);                           //  16.06
    if (strmatch(menu,"copytoclip")) m_copyto_clip(0,0);
@@ -861,7 +870,11 @@ void gallery_Lclick_func(int Nth)
 {
    char     *file;
 
-   if (checkpend("busy block mods")) return;                                     //  bugfix                             16.05
+   if (clicked_file) {                                                           //  lose memory of clicked thumbnail   16.09
+      zfree(clicked_file);
+      clicked_file = 0;
+   }
+   if (checkpend("busy block mods")) return;
    file = gallery(0,"find",Nth);
    if (! file) return;
    f_open(file,Nth,0,1);                                                         //  clicked file >> current file
@@ -950,7 +963,7 @@ void m_viewmode(GtkWidget *, cchar *fgwm)
       if (CEF) return;                                                           //  don't interrupt edit func.         15.04
       if (Fslideshow) return;                                                    //  no crash slide show                15.10
 
-      F1_help_topic = "world_maps_view";
+      F1_help_topic = "world_map_menu";
 
       gtk_widget_hide(Fhbox);                                  
       gtk_widget_hide(Ghbox);
@@ -963,7 +976,6 @@ void m_viewmode(GtkWidget *, cchar *fgwm)
       gdkwin = gtk_widget_get_window(Wdrawin);                                   //  GDK window
 
       if (! Wstate.fpxb) m_load_geomap(0,"default");                             //  no map loaded, load default map 
-
       gtk_window_set_title(MWIN,ZTX("Image Locations"));                         //  window title
       Fpaintnow();
    }
@@ -973,7 +985,7 @@ void m_viewmode(GtkWidget *, cchar *fgwm)
       if (CEF) return;                                                           //  don't interrupt edit func.
       if (Fslideshow) return;                                                    //  no crash slide show
 
-      F1_help_topic = "OSM_maps_view";
+      F1_help_topic = "OSM_map_view";
 
       gtk_widget_hide(Fhbox);                                  
       gtk_widget_hide(Ghbox);
