@@ -2,7 +2,7 @@
    zfuncs.h      include file for zfuncs functions
 
    Copyright 2006-2016 Michael Cornelison
-   source URL:  kornelic.net
+   source URL:  kornelix.net
    contact: kornelix@posteo.de
 
    This program is free software: you can redistribute it and/or modify
@@ -273,10 +273,10 @@ void Qtext_close(Qtext *qtext);
 
 //  application initialization and administration ===============================
 
-int zinitapp(cchar *appname, cchar *userdir = 0);                                //  initz. app directories and files
+int zinitapp(cchar *appname, cchar *homedir = 0);                                //  initz. app directories and files
 
 cchar * get_zprefix();                                                           //  get /usr or /usr/local  ... 
-cchar * get_zuserdir();                                                          //  get /home/user/.appname/
+cchar * get_zhomedir();                                                          //  get /home/user/.appname/
 cchar * get_zdatadir();                                                          //  get data directory
 cchar * get_zdocdir();                                                           //  get document directory
 cchar * get_zicondir();                                                          //  get icon directory
@@ -305,6 +305,7 @@ cchar * ZTX_missing(int &ftf);
 *********************************************************************************/
 
 void zmainloop(int skip = 0);                                                    //  do main loop, process menu events
+void zmainsleep(float secs);                                                     //  do main loop and sleep designated time
 void zthreadcrash();                                                             //  crash if thread is not main() thread
 
 //  text window print and read utilities
@@ -419,7 +420,6 @@ struct zwidget  {
       int         expand;                          //  widget is expandable flag
       int         space;                           //  extra padding space (pixels)
       int         wrap;                            //  wrap mode for edit widget
-      int         stopKB;                          //  stop propagation of KB events to parent
       int         rescale;                         //  widget is rescaled for more resolution
       float       lval, nval, hval;                //  scale range and neutral value
       GtkWidget   *widget;                         //  GTK widget pointer
@@ -434,7 +434,6 @@ struct zdialog  {
       int         disabled;                        //  widget signals/events are disabled
       int         saveposn;                        //  save and recall window position each use
       int         saveinputs;                      //  save and recall user inputs each use
-      int         stopKB;                          //  flag, next KB event will be ignored
       GtkWidget   *parent;                         //  parent window or null
       cchar       *compbutton[zdmaxbutts];         //  dialog completion button labels
       GtkWidget   *compwidget[zdmaxbutts];         //  dialog completion button widgets
@@ -468,7 +467,7 @@ int zdialog_rescale(zdialog *zd, cchar *wname, float, float, float);
 
 typedef int zdialog_event(zdialog *zd, cchar *name);                             //  widget event callback function
 int zdialog_run(zdialog *zd, zdialog_event = 0, cchar *posn = 0);                //  run dialog, handle events
-void KBstate(GdkEventKey *event, int state);                                     //  extern: pass KB events to main app
+void KBevent(GdkEventKey *event);                                                //  extern: pass KB events to main app
 
 int zdialog_send_event(zdialog *zd, cchar *event);                               //  send an event to an active dialog
 int zdialog_send_response(zdialog *zd, int zstat);                               //  complete a dialog, set status
